@@ -14,7 +14,8 @@ np.seterr(divide='ignore', invalid='ignore')
 
 ' a function for time-by-time decoding for EEG-like data (cross validation) '
 
-def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, nfolds=5, nrepeats=2, smooth=True):
+def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, nfolds=5, nrepeats=2,
+                        normalization=False, smooth=True):
 
     """
     Conduct time-by-time decoding for EEG-like data (cross validation)
@@ -26,7 +27,7 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=
         The shape of data must be [n_subs, n_trials, n_chls, n_ts]. n_subs, n_trials, n_chls and n_ts represent the
         number of subjects, the number of trails, the number of channels and the number of time-points.
     labels : array
-        The labels of each trials.
+        The labels of each trial.
         The shape of labels must be [n_subs, n_trials]. n_subs and n_trials represent the number of subjects and the
         number of trials.
     n : int. Default is 2.
@@ -43,10 +44,12 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=
     time_step : int. Default is 5.
         The time step size for each time of decoding.
     nfolds : int. Default is 5.
-        Number of folds.
+        The number of folds.
         k should be at least 2.
     nrepeats : int. Default is 2.
         The times for iteration.
+    normalization : boolean True or False. Default is False.
+        Normalize the data or not.
     smooth : boolean True or False. Default is True.
         Smooth the decoding result or not.
 
@@ -150,14 +153,20 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=
                     fold_index = 0
                     for train_index, test_index in kf.split(xt, y):
 
-                        scaler = StandardScaler()
-                        x_train = scaler.fit_transform(xt[train_index])
-                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                        svm.fit(x_train, y[train_index])
-                        subacc[i, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
+                        if normalization is False:
 
-                        percent = (
-                                              sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index) / total * 100
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(xt[train_index], y[train_index])
+                            subacc[i, t, fold_index] = svm.score(xt[test_index], y[test_index])
+
+                        if normalization is True:
+                            scaler = StandardScaler()
+                            x_train = scaler.fit_transform(xt[train_index])
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(x_train, y[train_index])
+                            subacc[i, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
+
+                        percent = (sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index + 1) / total * 100
                         show_progressbar("Calculating", percent)
 
                         if sub == (nsubs - 1) and i == (nrepeats - 1) and t == (newnts - 1) and fold_index == (
@@ -230,13 +239,19 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=
                     fold_index = 0
                     for train_index, test_index in kf.split(xt, y):
 
-                        scaler = StandardScaler()
-                        x_train = scaler.fit_transform(xt[train_index])
-                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                        svm.fit(x_train, y[train_index])
-                        subacc[i, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
+                        if normalization is True:
+                            scaler = StandardScaler()
+                            x_train = scaler.fit_transform(xt[train_index])
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(x_train, y[train_index])
+                            subacc[i, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
 
-                        percent = (sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index) / total * 100
+                        if normalization is False:
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(xt[train_index], y[train_index])
+                            subacc[i, t, fold_index] = svm.score(xt[test_index], y[test_index])
+
+                        percent = (sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index + 1) / total * 100
                         show_progressbar("Calculating", percent)
 
                         if sub == (nsubs - 1) and i == (nrepeats - 1) and t == (newnts - 1) and fold_index == (
@@ -269,7 +284,8 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=
 
 ' a function for time-by-time decoding for EEG-like data (hold out) '
 
-def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, iter=10, test_size=0.3, smooth=True):
+def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, iter=10,
+                          test_size=0.3, normalization=False, smooth=True):
 
     """
     Conduct time-by-time decoding for EEG-like data (hold out)
@@ -281,7 +297,7 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_wi
         The shape of data must be [n_subs, n_trials, n_chls, n_ts]. n_subs, n_trials, n_chls and n_ts represent the
         number of subjects, the number of trails, the number of channels and the number of time-points.
     labels : array
-        The labels of each trials.
+        The labels of each trial.
         The shape of labels must be [n_subs, n_trials]. n_subs and n_trials represent the number of subjects and the
         number of trials.
     n : int. Default is 2.
@@ -302,6 +318,8 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_wi
     test_size : float. Default is 0.3.
         The proportion of the test set.
         test_size should be between 0.0 and 1.0.
+    normalization : boolean True or False. Default is False.
+        Normalize the data or not.
     smooth : boolean True or False. Default is True.
         Smooth the decoding result or not.
 
@@ -400,17 +418,28 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_wi
 
                 for t in range(newnts):
 
-                    percent = (sub * iter * newnts + i * newnts + t) / total * 100
+                    percent = (sub * iter * newnts + i * newnts + t + 1) / total * 100
                     show_progressbar("Calculating", percent)
 
-                    state = np.random.randint(0, 100)
-                    xt = x[:, :, t]
-                    x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size, random_state=state)
-                    scaler = StandardScaler()
-                    x_train = scaler.fit_transform(x_train)
-                    svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                    svm.fit(x_train, y_train)
-                    subacc[i, t] = svm.score(scaler.transform(x_test), y_test)
+                    if normalization is True:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        scaler = StandardScaler()
+                        x_train = scaler.fit_transform(x_train)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t] = svm.score(scaler.transform(x_test), y_test)
+
+                    if normalization is False:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t] = svm.score(x_test, y_test)
 
                     if sub == (nsubs - 1) and i == (iter - 1) and t == (newnts - 1):
                         print("\nDecoding finished!\n")
@@ -474,17 +503,28 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_wi
 
                 for t in range(newnts):
 
-                    percent = (sub * iter * newnts + i * newnts + t) / total * 100
+                    percent = (sub * iter * newnts + i * newnts + t + 1) / total * 100
                     show_progressbar("Calculating", percent)
 
-                    state = np.random.randint(0, 100)
-                    xt = x[:, :, t]
-                    x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size, random_state=state)
-                    scaler = StandardScaler()
-                    x_train = scaler.fit_transform(x_train)
-                    svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                    svm.fit(x_train, y_train)
-                    subacc[i, t] = svm.score(scaler.transform(x_test), y_test)
+                    if normalization is True:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        scaler = StandardScaler()
+                        x_train = scaler.fit_transform(x_train)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t] = svm.score(scaler.transform(x_test), y_test)
+
+                    if normalization is False:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t] = svm.score(x_test, y_test)
 
                     if sub == (nsubs - 1) and i == (iter - 1) and t == (newnts - 1):
                         print("\nDecoding finished!\n")
@@ -513,7 +553,8 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_wi
 
 ' a function for cross-temporal decoding for EEG-like data (cross validation) '
 
-def ct_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, nfolds=5, nrepeats=2, smooth=True):
+def ct_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, nfolds=5, nrepeats=2,
+                      normalization=False, smooth=True):
 
     """
     Conduct cross-temporal decoding for EEG-like data (cross validation)
@@ -525,7 +566,7 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5,
         The shape of data must be [n_subs, n_trials, n_chls, n_ts]. n_subs, n_trials, n_chls and n_ts represent the
         number of subjects, the number of trails, the number of channels and the number of time-points.
     labels : array
-        The labels of each trials.
+        The labels of each trial.
         The shape of labels must be [n_subs, n_trials]. n_subs and n_trials represent the number of subjects and the
         number of trials.
     n : int. Default is 2.
@@ -542,10 +583,12 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5,
     time_step : int. Default is 5.
         The time step size for each time of decoding.
     nfolds : int. Default is 5.
-        Number of folds.
+        The number of folds.
         nfolds should be at least 2.
     nrepeats : int. Default is 2.
         The times for iteration.
+    normalization : boolean True or False. Default is False.
+        Normalize the data or not.
     smooth : boolean True or False. Default is True.
         Smooth the decoding result or not.
 
@@ -651,25 +694,38 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5,
                     fold_index = 0
                     for train_index, test_index in kf.split(xt, y):
 
-                        scaler = StandardScaler()
-                        x_train = scaler.fit_transform(xt[train_index])
-                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                        svm.fit(x_train, y[train_index])
-                        subacc[i, t, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
-
-                        percent = (
-                                              sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index) / total * 100
+                        percent = (sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index + 1) / total * 100
                         show_progressbar("Calculating", percent)
 
-                        for tt in range(newnts - 1):
-                            if tt < t:
-                                xtt = x[:, :, tt]
-                                subacc[i, t, tt, fold_index] = svm.score(scaler.transform(xtt[test_index]),
-                                                                         y[test_index])
-                            if tt >= t:
-                                xtt = x[:, :, tt + 1]
-                                subacc[i, t, tt + 1, fold_index] = svm.score(scaler.transform(xtt[test_index]),
+                        if normalization is True:
+                            scaler = StandardScaler()
+                            x_train = scaler.fit_transform(xt[train_index])
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(x_train, y[train_index])
+                            subacc[i, t, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
+
+                            for tt in range(newnts - 1):
+                                if tt < t:
+                                    xtt = x[:, :, tt]
+                                    subacc[i, t, tt, fold_index] = svm.score(scaler.transform(xtt[test_index]),
                                                                              y[test_index])
+                                if tt >= t:
+                                    xtt = x[:, :, tt + 1]
+                                    subacc[i, t, tt + 1, fold_index] = svm.score(scaler.transform(xtt[test_index]),
+                                                                                 y[test_index])
+
+                        if normalization is False:
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(xt[train_index], y[train_index])
+                            subacc[i, t, t, fold_index] = svm.score(xt[test_index], y[test_index])
+
+                            for tt in range(newnts - 1):
+                                if tt < t:
+                                    xtt = x[:, :, tt]
+                                    subacc[i, t, tt, fold_index] = svm.score(xtt[test_index], y[test_index])
+                                if tt >= t:
+                                    xtt = x[:, :, tt + 1]
+                                    subacc[i, t, tt + 1, fold_index] = svm.score(xtt[test_index], y[test_index])
 
                         if sub == (nsubs - 1) and i == (nrepeats - 1) and t == (newnts - 1) and fold_index == (
                                 nfolds - 1):
@@ -743,25 +799,38 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5,
                     fold_index = 0
                     for train_index, test_index in kf.split(xt, y):
 
-                        scaler = StandardScaler()
-                        x_train = scaler.fit_transform(xt[train_index])
-                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                        svm.fit(x_train, y[train_index])
-                        subacc[i, t, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
-
-                        percent = (
-                                              sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index) / total * 100
+                        percent = (sub * nrepeats * newnts * nfolds + i * newnts * nfolds + t * nfolds + fold_index + 1) / total * 100
                         show_progressbar("Calculating", percent)
 
-                        for tt in range(newnts - 1):
-                            if tt < t:
-                                xtt = x[:, :, tt]
-                                subacc[i, t, tt, fold_index] = svm.score(scaler.transform(xtt[test_index]),
-                                                                         y[test_index])
-                            if tt >= t:
-                                xtt = x[:, :, tt + 1]
-                                subacc[i, t, tt + 1, fold_index] = svm.score(scaler.transform(xtt[test_index]),
+                        if normalization is True:
+                            scaler = StandardScaler()
+                            x_train = scaler.fit_transform(xt[train_index])
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(x_train, y[train_index])
+                            subacc[i, t, t, fold_index] = svm.score(scaler.transform(xt[test_index]), y[test_index])
+
+                            for tt in range(newnts - 1):
+                                if tt < t:
+                                    xtt = x[:, :, tt]
+                                    subacc[i, t, tt, fold_index] = svm.score(scaler.transform(xtt[test_index]),
                                                                              y[test_index])
+                                if tt >= t:
+                                    xtt = x[:, :, tt + 1]
+                                    subacc[i, t, tt + 1, fold_index] = svm.score(scaler.transform(xtt[test_index]),
+                                                                                 y[test_index])
+
+                        if normalization is False:
+                            svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                            svm.fit(xt[train_index], y[train_index])
+                            subacc[i, t, t, fold_index] = svm.score(xt[test_index], y[test_index])
+
+                            for tt in range(newnts - 1):
+                                if tt < t:
+                                    xtt = x[:, :, tt]
+                                    subacc[i, t, tt, fold_index] = svm.score(xtt[test_index], y[test_index])
+                                if tt >= t:
+                                    xtt = x[:, :, tt + 1]
+                                    subacc[i, t, tt + 1, fold_index] = svm.score(xtt[test_index], y[test_index])
 
                         if sub == (nsubs - 1) and i == (nrepeats - 1) and t == (newnts - 1) and fold_index == (
                                 nfolds - 1):
@@ -806,7 +875,8 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_opt="average", time_win=5,
 
 ' a function for cross-temporal decoding for EEG-like data (hold-out) '
 
-def ct_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, iter=10, test_size=0.3, smooth=True):
+def ct_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=5, time_step=5, iter=10, test_size=0.3,
+                        normalization=False, smooth=True):
 
     """
     Conduct cross-temporal decoding for EEG-like data (hold-out)
@@ -818,7 +888,7 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=
         The shape of data must be [n_subs, n_trials, n_chls, n_ts]. n_subs, n_trials, n_chls and n_ts represent the
         number of subjects, the number of trails, the number of channels and the number of time-points.
     labels : array
-        The labels of each trials.
+        The labels of each trial.
         The shape of labels must be [n_subs, n_trials]. n_subs and n_trials represent the number of subjects and the
         number of trials.
     n : int. Default is 2.
@@ -839,6 +909,8 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=
     test_size : float. Default is 0.3.
         The proportion of the test set.
         test_size should be between 0.0 and 1.0.
+    normalization : boolean True or False. Default is False.
+        Normalize the data or not.
     smooth : boolean True or False. Default is True.
         Smooth the decoding result or not.
 
@@ -937,28 +1009,50 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=
 
                 for t in range(newnts):
 
-                    percent = (sub * iter * newnts + i * newnts + t) / total * 100
+                    percent = (sub * iter * newnts + i * newnts + t + 1) / total * 100
                     show_progressbar("Calculating", percent)
 
-                    state = np.random.randint(0, 100)
-                    xt = x[:, :, t]
-                    x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size, random_state=state)
-                    scaler = StandardScaler()
-                    x_train = scaler.fit_transform(x_train)
-                    svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                    svm.fit(x_train, y_train)
-                    subacc[i, t, t] = svm.score(scaler.transform(x_test), y_test)
-                    for tt in range(newnts - 1):
-                        if tt < t:
-                            xtt = x[:, :, tt]
-                            x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
-                                                                                 random_state=state)
-                            subacc[i, t, tt] = svm.score(scaler.transform(x_testt), y_test)
-                        if tt >= t:
-                            xtt = x[:, :, tt + 1]
-                            x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
-                                                                                 random_state=state)
-                            subacc[i, t, tt + 1] = svm.score(scaler.transform(x_testt), y_test)
+                    if normalization is True:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        scaler = StandardScaler()
+                        x_train = scaler.fit_transform(x_train)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t, t] = svm.score(scaler.transform(x_test), y_test)
+                        for tt in range(newnts - 1):
+                            if tt < t:
+                                xtt = x[:, :, tt]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt] = svm.score(scaler.transform(x_testt), y_test)
+                            if tt >= t:
+                                xtt = x[:, :, tt + 1]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt + 1] = svm.score(scaler.transform(x_testt), y_test)
+
+                    if normalization is False:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t, t] = svm.score(x_test, y_test)
+                        for tt in range(newnts - 1):
+                            if tt < t:
+                                xtt = x[:, :, tt]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt] = svm.score(x_testt, y_test)
+                            if tt >= t:
+                                xtt = x[:, :, tt + 1]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt + 1] = svm.score(x_testt, y_test)
 
                     if sub == (nsubs - 1) and i == (iter - 1) and t == (newnts - 1):
                         print("\nDecoding finished!\n")
@@ -1022,28 +1116,50 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=
 
                 for t in range(newnts):
 
-                    percent = (sub * iter * newnts + i * newnts + t) / total * 100
+                    percent = (sub * iter * newnts + i * newnts + t + 1) / total * 100
                     show_progressbar("Calculating", percent)
 
-                    state = np.random.randint(0, 100)
-                    xt = x[:, :, t]
-                    x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size, random_state=state)
-                    scaler = StandardScaler()
-                    x_train = scaler.fit_transform(x_train)
-                    svm = SVC(kernel='linear', tol=1e-4, probability=False)
-                    svm.fit(x_train, y_train)
-                    subacc[i, t, t] = svm.score(scaler.transform(x_test), y_test)
-                    for tt in range(newnts - 1):
-                        if tt < t:
-                            xtt = x[:, :, tt]
-                            x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
-                                                                                 random_state=state)
-                            subacc[i, t, tt] = svm.score(scaler.transform(x_testt), y_test)
-                        if tt >= t:
-                            xtt = x[:, :, tt + 1]
-                            x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
-                                                                                 random_state=state)
-                            subacc[i, t, tt + 1] = svm.score(scaler.transform(x_testt), y_test)
+                    if normalization is True:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        scaler = StandardScaler()
+                        x_train = scaler.fit_transform(x_train)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t, t] = svm.score(scaler.transform(x_test), y_test)
+                        for tt in range(newnts - 1):
+                            if tt < t:
+                                xtt = x[:, :, tt]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt] = svm.score(scaler.transform(x_testt), y_test)
+                            if tt >= t:
+                                xtt = x[:, :, tt + 1]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt + 1] = svm.score(scaler.transform(x_testt), y_test)
+
+                    if normalization is False:
+                        state = np.random.randint(0, 100)
+                        xt = x[:, :, t]
+                        x_train, x_test, y_train, y_test = train_test_split(xt, y, test_size=test_size,
+                                                                            random_state=state)
+                        svm = SVC(kernel='linear', tol=1e-4, probability=False)
+                        svm.fit(x_train, y_train)
+                        subacc[i, t, t] = svm.score(x_test, y_test)
+                        for tt in range(newnts - 1):
+                            if tt < t:
+                                xtt = x[:, :, tt]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt] = svm.score(x_testt, y_test)
+                            if tt >= t:
+                                xtt = x[:, :, tt + 1]
+                                x_train, x_testt, y_train, y_test = train_test_split(xtt, y, test_size=test_size,
+                                                                                     random_state=state)
+                                subacc[i, t, tt + 1] = svm.score(x_testt, y_test)
 
                     if sub == (nsubs - 1) and i == (iter - 1) and t == (newnts - 1):
                         print("\nDecoding finished!\n")
@@ -1085,8 +1201,8 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_opt="average", time_win=
 
 ' a function for unidirectional transfer decoding for EEG-like data '
 
-def unidirectional_transfer_decoding_holdout(data1, labels1, data2, labels2, n=2, navg=5, time_opt="average",
-                                             time_win=5, time_step=5, iter=10, smooth=True):
+def unidirectional_transfer_decoding(data1, labels1, data2, labels2, n=2, navg=5, time_opt="average", time_win=5,
+                                     time_step=5, iter=10, normalization=False, smooth=True):
 
     """
     Conduct unidirectional transfer decoding for EEG-like data
@@ -1098,13 +1214,13 @@ def unidirectional_transfer_decoding_holdout(data1, labels1, data2, labels2, n=2
         The shape of data must be [n_subs, n_trials, n_chls, n_ts]. n_subs, n_trials, n_chls and n_ts represent the
         number of subjects, the number of trails, the number of channels and the number of time-points.
     labels1 : array
-        The labels of each trials under condition1.
+        The labels of each trial under condition1.
         The shape of labels must be [n_subs, n_trials]. n_subs and n_trials represent the number of subjects and the
         number of trials.
     data2 : array
         The neural data under condition2.
     labels2 : array
-        The labels of each trials under condition2.
+        The labels of each trial under condition2.
     n : int. Default is 2.
         The number of categories for classification.
     navg : int. Default is 5.
@@ -1120,6 +1236,8 @@ def unidirectional_transfer_decoding_holdout(data1, labels1, data2, labels2, n=2
         The time step size for each time of decoding.
     iter : int. Default is 10.
         The times for iteration.
+    normalization : boolean True or False. Default is False.
+        Normalize the data or not.
     smooth : boolean True or False. Default is True.
         Smooth the decoding result or not.
 
@@ -1296,7 +1414,7 @@ def unidirectional_transfer_decoding_holdout(data1, labels1, data2, labels2, n=2
 
                 for t in range(newnts1):
 
-                    percent = (sub * iter * newnts1 + i * newnts1 + t) / total * 100
+                    percent = (sub * iter * newnts1 + i * newnts1 + t + 1) / total * 100
                     show_progressbar("Calculating", percent)
 
                     scaler = StandardScaler()
@@ -1402,7 +1520,7 @@ def unidirectional_transfer_decoding_holdout(data1, labels1, data2, labels2, n=2
 
                 for t in range(newnts1):
 
-                    percent = (sub * iter * newnts1 + i * newnts1 + t) / total * 100
+                    percent = (sub * iter * newnts1 + i * newnts1 + t + 1) / total * 100
                     show_progressbar("Calculating", percent)
 
                     scaler = StandardScaler()
@@ -1451,10 +1569,10 @@ def unidirectional_transfer_decoding_holdout(data1, labels1, data2, labels2, n=2
         return acc
 
 
-' a function for conducting bidirectional transfer decoding for EEG-like data '
+' a function for bidirectional transfer decoding for EEG-like data '
 
 def bidirectional_transfer_decoding(data1, labels1, data2, labels2, n=2, navg=5, time_opt="average", time_win=5,
-                                    time_step=5, iter=10, smooth=True):
+                                    time_step=5, iter=10, normalization=False, smooth=True):
 
     """
     Conduct bidirectional transfer decoding for EEG-like data
@@ -1488,6 +1606,8 @@ def bidirectional_transfer_decoding(data1, labels1, data2, labels2, n=2, navg=5,
         The time step size for each time of decoding.
     iter : int. Default is 10.
         The times for iteration.
+    normalization : boolean True or False. Default is False.
+        Normalize the data or not.
     smooth : boolean True or False. Default is True.
         Smooth the decoding result or not.
 
@@ -1501,10 +1621,11 @@ def bidirectional_transfer_decoding(data1, labels1, data2, labels2, n=2, navg=5,
         The shape of accuracies is [n_subs, int((n_ts2-time_win)/time_step)+1, int((n_ts1-time_win)/time_step)+1].
     """
 
-    Con1toCon2_accuracies, Con2toCon1_accuracies = unidirectional_transfer_decoding_holdout(data1, labels1, data2,
+    Con1toCon2_accuracies, Con2toCon1_accuracies = unidirectional_transfer_decoding(data1, labels1, data2,
                                     labels2, n=n, navg=navg, time_opt=time_opt, time_win=time_win, time_step=time_step,
-                                    iter=iter, smooth=smooth), unidirectional_transfer_decoding_holdout(data1, labels1,
-                                    data2, labels2, n=n, navg=navg, time_opt=time_opt, time_win=time_win,
-                                    time_step=time_step, iter=iter, smooth=smooth)
+                                    iter=iter, normalization=normalization, smooth=smooth), \
+                                    unidirectional_transfer_decoding(data1, labels1, data2, labels2, n=n, navg=navg,
+                                    time_opt=time_opt, time_win=time_win, time_step=time_step, iter=iter,
+                                    normalization=normalization, smooth=smooth)
 
     return Con1toCon2_accuracies, Con2toCon1_accuracies
\ No newline at end of file
